<?xml version="1.0"?>
<TS>
  <context>
    <name>About</name>
    <message>
      <source>Done</source>
      <translation>Hecho</translation>
    </message>
  </context>
  <context>
    <name>CaProperties</name>
    <message>
      <source>CA Properties</source>
      <translation>Propiedades de la CA</translation>
    </message>
    <message>
      <source>Use random Serial numbers</source>
      <translation>Usar números de Serie aleatorios</translation>
    </message>
    <message>
      <source>Days until next CRL issuing</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Default template</source>
      <translation>Plantilla predeterminada</translation>
    </message>
    <message>
      <source>Next serial for signing</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>CertDetail</name>
    <message>
      <source>Details of the Certificate</source>
      <translation>Detalles del Certificado</translation>
    </message>
    <message>
      <source>S&amp;tatus</source>
      <translation>Estado</translation>
    </message>
    <message>
      <source>Serial</source>
      <translation>Número de serie</translation>
    </message>
    <message>
      <source>The serial number of the certificate</source>
      <translation>El número de serie del certificado</translation>
    </message>
    <message>
      <source>The internal name of the certificate in the database</source>
      <translation>El nombre interno del certificado en la base de datos</translation>
    </message>
    <message>
      <source>Internal name</source>
      <translation>Nombre interno</translation>
    </message>
    <message>
      <source>Signature algorithm</source>
      <translation>Firma</translation>
    </message>
    <message>
      <source>Signature</source>
      <translation>Firma</translation>
    </message>
    <message>
      <source>Key</source>
      <translation>Clave</translation>
    </message>
    <message>
      <source>Fingerprints</source>
      <translation>Huellas digitales</translation>
    </message>
    <message>
      <source>SHA1</source>
      <translation>SHA1</translation>
    </message>
    <message>
      <source>MD5</source>
      <translation>MD5</translation>
    </message>
    <message>
      <source>A SHA-1 hashsum of the certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>An md5 hashsum of the certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Validity</source>
      <translation>Validez</translation>
    </message>
    <message>
      <source>The time since the certificate is valid</source>
      <translation>El momento desde el que el certificado es válido</translation>
    </message>
    <message>
      <source>The time until the certificate is valid</source>
      <translation>El momento hasta el que el certificado es válido</translation>
    </message>
    <message>
      <source>&amp;Subject</source>
      <translation>As&amp;unto</translation>
    </message>
    <message>
      <source>&amp;Issuer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Attributes</source>
      <translation>Atributos</translation>
    </message>
    <message>
      <source>&amp;Extensions</source>
      <translation>&amp;Extensiones</translation>
    </message>
    <message>
      <source>Show config</source>
      <translation>Mostrar configuración</translation>
    </message>
    <message>
      <source>Show extensions</source>
      <translation>Mostrar extensiones</translation>
    </message>
    <message>
      <source>Not available</source>
      <translation>No disponible</translation>
    </message>
    <message>
      <source>Details of the certificate</source>
      <translation>Detalles del certificado</translation>
    </message>
    <message>
      <source>Signer unknown</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Self signed</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Not trusted</source>
      <translation>No fiable</translation>
    </message>
    <message>
      <source>Trusted</source>
      <translation>Fiable</translation>
    </message>
    <message>
      <source>Revoked: </source>
      <translation>Revocado: </translation>
    </message>
    <message>
      <source>Not valid</source>
      <translation>No válido</translation>
    </message>
    <message>
      <source>Valid</source>
      <translation>Válido</translation>
    </message>
    <message>
      <source>Details of the certificate signing request</source>
      <translation>Detalles de la solicitud</translation>
    </message>
  </context>
  <context>
    <name>CertExtend</name>
    <message>
      <source>Certificate renewal</source>
      <translation>Renovación de certificado</translation>
    </message>
    <message>
      <source>This will create a new certificate as a copy of the old one with a new serial number and adjusted validity values.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Validity</source>
      <translation>Validez</translation>
    </message>
    <message>
      <source>Not before</source>
      <translation>No antes de</translation>
    </message>
    <message>
      <source>Not after</source>
      <translation>No después de</translation>
    </message>
    <message>
      <source>Time range</source>
      <translation>Rango de tiempo</translation>
    </message>
    <message>
      <source>No well-defined expiration</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Apply</source>
      <translation>Aplicar</translation>
    </message>
    <message>
      <source>Days</source>
      <translation>Días</translation>
    </message>
    <message>
      <source>Months</source>
      <translation>Meses</translation>
    </message>
    <message>
      <source>Years</source>
      <translation>Años</translation>
    </message>
    <message>
      <source>Midnight</source>
      <translation>Medianoche</translation>
    </message>
    <message>
      <source>The certificate will be earlier valid than the signer. This is probably not what you want.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Edit times</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Abort rollout</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Continue rollout</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Adjust date and continue</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The certificate will be longer valid than the signer. This is probably not what you want.</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>CertView</name>
    <message>
      <source>There was no key found for the Certificate: </source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import Certificate signing request</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>ClickLabel</name>
    <message>
      <source>Double click for details</source>
      <translation>Haga doble click para obtener detalles</translation>
    </message>
  </context>
  <context>
    <name>CrlDetail</name>
    <message>
      <source>Details of the Revocation list</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Status</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Version</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Signature</source>
      <translation>Firma</translation>
    </message>
    <message>
      <source>Signed by</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Name</source>
      <translation>Nombre</translation>
    </message>
    <message>
      <source>The internal name of the CRL in the database</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>issuing dates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Next Update</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Last Update</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Issuer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Extensions</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Revocation list</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>0</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Serial</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revocation</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Reason</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Invalidation</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Failed</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unknown signer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Verification not possible</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unknown certificate</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>ExportCert</name>
    <message>
      <source>X509 Certificates ( *.cer *.crt *.p12 *.p7b);;All files ( * )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>DER is a binary format of the Certificate
PEM is a base64 encoded Certificate
PKCS#7 is an official Certificate exchange format
PKCS#12 is an encrypted official Key-Certificate exchange format
</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the filename for the certificate.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certificate export</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>ExportDer</name>
    <message>
      <source>All files ( * )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>DER is a binary format
PEM is a base64 encoded DER file
</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>ExportDialog</name>
    <message>
      <source>...</source>
      <translation>...</translation>
    </message>
    <message>
      <source>Filename</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the filename</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Export Format</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The file: '%1' already exists!</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Overwrite</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Do not overwrite</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>ExportKey</name>
    <message>
      <source>When exporting the private key it should be encrypted.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>When exporting the private part, it should be encrypted.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>E&amp;xport the private part of the Key too</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Export as PKCS#8</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Encrypt the Key with a password</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Private keys ( *.pem *.der *.pk8 );;All files ( * )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>DER is a binary format of the key without encryption
PEM is a base64 encoded key with optional encryption
PKCS#8 is an encrypted official Key-exchange format</source>
      <translation>DER es un formato binario sin cifrado
PEM es un formato texto bas64 con cifrado opcional
PKCS#8 es un formato estandar de intercambio de claves</translation>
    </message>
    <message>
      <source>Please enter the filename for the key.</source>
      <translation>Introduzca nombre de fichero que contendrá la clave.</translation>
    </message>
    <message>
      <source>Public key export</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Key export</source>
      <translation>Exportar clave</translation>
    </message>
  </context>
  <context>
    <name>Help</name>
    <message>
      <source>&lt;&lt;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&gt;&gt;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Done</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>ImportMulti</name>
    <message>
      <source>Import PKI Items</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import &amp;All</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Import</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Done</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Remove from list</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Details</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete from token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Rename on token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>
Name: %1
Model: %2
Serial: %3</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Manage security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The type of the Item '%1' is not recognized</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Details of the item '%1' cannot be shown</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The type of the item '%1' is not recognized</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The file '%1' did not contain PKI data</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The %1 files: '%2' did not contain PKI data</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>KeyDetail</name>
    <message>
      <source>Name</source>
      <translation>Nombre</translation>
    </message>
    <message>
      <source>The internal name of the key used by xca</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Manufacturer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Serial</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Public Exponent</source>
      <translation>Exponente público</translation>
    </message>
    <message>
      <source>Keysize</source>
      <translation>Tamaño de clave</translation>
    </message>
    <message>
      <source>Private Exponent</source>
      <translation>Exponente secreto</translation>
    </message>
    <message>
      <source>Modulus</source>
      <translation>Módulo</translation>
    </message>
    <message>
      <source>Details of the %1 key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Not available</source>
      <translation>Disponible</translation>
    </message>
    <message>
      <source>Token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Security token ID:%1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Available</source>
      <translation>Disponible</translation>
    </message>
    <message>
      <source>Sub prime</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Public key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Private key</source>
      <translation>Exponente secreto</translation>
    </message>
    <message>
      <source>Curve name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unknown key</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>MainWindow</name>
    <message>
      <source>Private Keys</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;New Key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Export</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Import</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Import PFX (PKCS#12)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Show Details</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Delete</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certificate signing requests</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;New Request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certificates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;New Certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import &amp;PKCS#12</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import P&amp;KCS#7</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Plain View</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Templates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;New template</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Ch&amp;ange Template</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revocation lists</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Using or exporting private keys will not be possible without providing the correct password</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Database</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No deleted items found</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;File</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;New DataBase</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Open DataBase</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Generate DH parameter</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Set as default DataBase</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Close DataBase</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Dump DataBase</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>C&amp;hange DataBase password</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Import old db_dump</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Undelete items</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Options</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Exit</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>I&amp;mport</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Keys</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Requests</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#12</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#7</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Template</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revocation list</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PEM file</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>paste PEM file</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Manage Security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Init Security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Change PIN</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Change &amp;SO PIN</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Init PIN</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Help</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Content</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;About</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Donations</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Database dump ( *.dump );;All files ( * )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import password</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the password of the old database</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Password verification error. Ignore keys ?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import anyway</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Cancel</source>
      <translation>Cancelar</translation>
    </message>
    <message>
      <source>no such option: %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import PEM data</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the original SO PIN (PUK) of the token '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the new SO PIN (PUK) of the token '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The new label of the token '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The token '%1' did not contain any keys or certificates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>New Password</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the new password to encrypt your private keys in the database-file</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter a password, that will be used to encrypt your private keys in the database file:
%1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Password verify error, please try again</source>
      <translation>Contraeña incorrecta, inténtelo de nuevo</translation>
    </message>
    <message>
      <source>Password</source>
      <translation>Contraseña</translation>
    </message>
    <message>
      <source>Please enter the password for unlocking the database:
%1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The following error occured:</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Copy to Clipboard</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Diffie-Hellman parameters are needed for different applications, but not handled by XCA.
Please enter the DH parameter bits</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Error opening file: '%1': %2</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>NewCrl</name>
    <message>
      <source>Create CRL</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Dates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>last update</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>next update</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Days</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Months</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Years</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Midnight</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Apply</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Hashing algorithm</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Extensions</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Authority key identifier</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Subject alternative name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>CRL Number</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revokation reasons</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>NewKey</name>
    <message>
      <source>New key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please give a name to the new key and select the desired keysize</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Key properties</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Name</source>
      <translation>Nombre</translation>
    </message>
    <message>
      <source>The internal name of the new key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>New Key</source>
      <translation>Nueva clave</translation>
    </message>
    <message>
      <source>Curve</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Keysize</source>
      <translation>Tamaño de clave</translation>
    </message>
    <message>
      <source>Usually 1024 or 2048 bit keys are used</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Keytype</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Create</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>NewX509</name>
    <message>
      <source>Create</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Source</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Signing request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>A certificate signing request can be signed, even if the private key of the request is not available. This is the intention of a CSR:
Getting signed by a CA certificate, whoes certificate of course must be in the database
Of course you need the private key of the CSR if you want to create a self-signed cert from it.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Show request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Sign this Certificate signing &amp;request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Copy extensions from the request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Modify subject of the request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Signing</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Create a &amp;self signed certificate with the serial</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>If you leave this blank the serial 00 will be used</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Use &amp;this Certificate for signing</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>All certificates in your database that can create valid signatures</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>This list contains all certificates with the CA-flag set to true and whoes private key is present in the key-database.
If this list is disabled, you only can create a self-signed certificate.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Signature algorithm</source>
      <translation>Firma</translation>
    </message>
    <message>
      <source>Template for the new certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>All available templates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>This list contains all templates from the toplevel template Tab</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Apply extensions</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Apply subject</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Apply all</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Subject</source>
      <translation>Sujeto</translation>
    </message>
    <message>
      <source>Organisation</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>This name is only used internally and does not appear in the resulting certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Must be exactly 2 letter of size (DE, UK)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Country code</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>State or Province</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Locality</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Organisational unit</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>E-Mail address</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Internal name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Common name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Add</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Private key</source>
      <translation>Exponente secreto</translation>
    </message>
    <message>
      <source>This list only contains unused keys</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Used keys too</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Generate a new key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Extensions</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Basic constraints</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Type</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>If this will become a CA certificate or not</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Set this to TRUE if you want to create a CA certificate that signs other certificates.
This is always set to FALSE for client or server certificates. In most cases self-signed certificates are CA certificates.
Self-signed non-CA certificates are unusual although they are possible.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Not defined</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certification Authority</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>End Entity</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Path length</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>How much CAs may be below this.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>If this is left empty the pathlen is not included in the certificate. Otherwise it distinguishes the count of chained CA certificates below this one.
A pathlen of 0 means, that this certificate may not issue other sub-CA certificates. Although it can do it, all chain-checking algorithms in e.g. your browser or openssl will (should) fail.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The basic constraints should always be critical</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Key identifier</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Creates a hash of the key following the PKIX guidelines</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Copy the Subject Key Identifier from the issuer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>If this box is checked an attempt is made to copy the subject key identifier from the signing certificate.
It also copies the issuer and serial number from the issuer certificate. Normally this will only be done if the keyid option fails.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Validity</source>
      <translation>Validez</translation>
    </message>
    <message>
      <source>Not before</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Not after</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Time range</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Days</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Months</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Years</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Apply</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Set the time to 00:00:00 and 23:59:59 respectively</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Midnight</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No well-defined expiration</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Authority Info Access</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>CRL distribution point</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>issuer alternative name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>URI:</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>This is a multi-valued extension that supports all the literal options of subject alternative name. Of the few software packages that currentlyi nterpret this extension most only interpret the URI option.
Currently each option will set a new DistributionPoint with the fullName field set to the given value.
Other fields like cRLissuer and reasons cannot currently be set or displayed: at this time no examples were available that used these fields.
If you see this extension with &lt;UNSUPPORTED&gt; when you attempt to print it out or it doesn't appear to display correctly then let steve know, including the certificate (mail steve at openssl dot org) .
Examples:
URI:http://www.myhost.com/myca.crl
URI:http://www.my.com/my.crl, URI:http://www.oth.com/my.crl</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>can be altered by the file "aia.txt"</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Edit</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>DNS: IP: URI: email: RID:</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The authority information access extension gives details about how to access certain information relating to the CA. Its syntax is accessOID;location where 'location' has the same syntax as subject alternative name (except that email:copy is not supported). accessOID can be any valid OID but only certain values are meaningful for example OCSP and caIssuers. OCSP gives the location of an OCSP responder: this is used by Netscape PSM and other software.
Example:
OCSP;URI:http://ocsp.my.host/
caIssuers;URI:http://my.ca/ca.html</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The subject alternative name extension allows various literal values to be used. These include "email" (an email address) , "URI" a uniform resource indicator, "DNS" (a DNS domain name) , RID (a registered ID: OBJECT IDENTIFIER) and IP (an IP address).
Examples:
email:my@other.address, IP: 1.1.1.1 , URI:http://my.url.here/
email:my@other.address, RID:1.2.3.4, DNS: ns.server.tld</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>subject alternative name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The issuer alternative name extension allows various literal values to be used. These include "email" (an email address) , "URI" a uniform resource indicator, "DNS" (a DNS domain name), RID (a registered ID: OBJECT IDENTIFIER) and IP (an IP address).
Examples:
email:my@other.address, IP: 1.1.1.1 , URI:http://my.url.here/
email:my@other.address, RID:1.2.3.4, DNS: ns.server.tld</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Key usage</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Extended key usage</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Netscape</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>CA Revocation URL</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revocation URL</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>SSL server name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certificate renewal URL</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Comment</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>CA policy URL</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Base URL</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>If you know a more pretty one tell me</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Advanced</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Validate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Create a &amp;self signed certificate with a MD5-hashed QA serial</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Create Certificate signing request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>minimum size: %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>maximum size: %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>only a-z A-Z 0-9 '()+,-./:=?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>only 7-bit clean characters</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>XCA template</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Create x509 Certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>From PKCS#10 request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Other Tabs</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Advanced Tab</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Errors</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Abort rollout</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The following length restrictions of RFC3280 are violated:</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Edit subject</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Continue rollout</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The verification of the Certificate request failed.
The rollout should be aborted.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Continue anyway</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The internal name and the common name are empty.
Please set at least the internal name.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Edit name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>There is no Key selected for signing.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Select key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The following distinguished name entries are empty:
%1
though you have declared them as mandatory in the options menu.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The key you selected for signing is not a private one.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Select other signer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Select other key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The certificate will be earlier valid than the signer. This is probably not what you want.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Edit dates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Adjust date and continue</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The certificate will be longer valid than the signer. This is probably not what you want.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The certificate will be out of date before it becomes valid. You most probably mixed up both dates.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The certificate contains duplicated extensions. Check the validation on the advanced tab.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Edit extensions</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Configfile error on line %1
</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>Options</name>
    <message>
      <source>XCA Options</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Mandatory subject entries</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Add</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Default hash algorithm</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>String types</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Suppress success messages</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#11 provider</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Remove</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Printable string or UTF8 (default)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKIX recommendation in RFC2459</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No BMP strings, only printable and T61</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>UTF8 strings only (RFC2459)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>All strings</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Load failed</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>PwDialog</name>
    <message>
      <source>Password</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The password is parsed as 2-digit hex code. It must have an equal number of digits (0-9 and a-f)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Take as HEX string</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Repeat %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>%1 missmatch</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Hex password must only contain the characters '0' - '9' and 'a' - 'f' and it must consist of an even number of characters</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>E&amp;xit</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Undefined</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>DB: Rename: '%1' already in use</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>DB: Entry to rename not found: %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>DB: Write error %1 - %2</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Out of data</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Error finding endmarker of string</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Out of Memory at %1:%2</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>All files ( * )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKI Keys ( *.pem *.der *.key );;PKCS#8 Keys ( *.p8 *.pk8 );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import RSA key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#10 CSR ( *.pem *.der *.csr );;Netscape Request ( *.spkac *.spc );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import Request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certificates ( *.pem *.der *.crt *.cer );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import X.509 Certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#7 data ( *.p7s *.p7m *.p7b );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import PKCS#7 Certificates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#12 Certificates ( *.p12 *.pfx );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import PKCS#12 Private Certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>XCA templates ( *.xca );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import XCA Templates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revocation lists ( *.pem *.der *.crl );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import Certificate Revocation List</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>XCA Databases ( *.xdb );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Open XCA Database</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#11 library ( *.dll );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#11 library ( *.dylib *.so );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#11 library ( *.so );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Open PKCS#11 shared library</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PEM files ( *.pem );;</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Load PEM encoded file</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the PIN on the PinPad</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the SO PIN (PUK) of the token %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the PIN of the token %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No Security token found</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Select</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the new SO PIN (PUK) for the token: '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the new PIN for the token: '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Required PIN size: %1 - %2</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Failed to open PKCS11 library: %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#11 function '%1' failed: %2</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#11 function '%1' failed: %2
In library %3
%4</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Invalid</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>%1 is shorter than %2 bytes: '%3'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>%1 is longer than %2 bytes: '%3'</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>Revoke</name>
    <message>
      <source>Revokation details</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Invalid since</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revokation reason</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>SelectToken</name>
    <message>
      <source>Select Token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please select the security token</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>TrustState</name>
    <message>
      <source>Set trustment of the Certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Trustment</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Never trust this certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Only &amp;trust this certificate, if we trust the signer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>&amp;Always trust this certificate</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>Validity</name>
    <message>
      <source>yyyy-MM-dd hh:mm</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_base</name>
    <message>
      <source>Internal name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Reset</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Subject entries</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Paste PEM data</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Columns</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_crl</name>
    <message>
      <source>Signer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Internal name of the signer</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No. revoked</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Number of revoked certificates</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Last update</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Next update</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>CRL number</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The revokation list already exists in the database as:
'%1'
and so it was not imported</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>CRL ( *.pem *.der *.crl )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revokation list export</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Rename</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Export</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Clipboard</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>File</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_key</name>
    <message>
      <source>Type</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Size</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Use</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Password</source>
      <translation>Contraseña</translation>
    </message>
    <message>
      <source>The key is already in the database as:
'%1'
and is not going to be imported</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The database already contains the public part of the imported key as
'%1
and will be completed by the new, private part of the key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Key size too small !</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>You are sure to create a key of the size: %1 ?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Shall the original key '%1' be replaced by the key on the token?
This will delete the key '%1' and make it unexportable</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>New Key</source>
      <translation>Nueva clave</translation>
    </message>
    <message>
      <source>Import</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Rename</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Show Details</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Export</source>
      <translation>Exportar</translation>
    </message>
    <message>
      <source>Change password</source>
      <translation>Cambiar contraseña</translation>
    </message>
    <message>
      <source>Reset password</source>
      <translation>Restablecer la contraseña</translation>
    </message>
    <message>
      <source>Change PIN</source>
      <translation>Cambiar PIN</translation>
    </message>
    <message>
      <source>Init PIN with SO PIN (PUK)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Change SO PIN (PUK)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Store on Security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Tried to change password of a token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Tried to change PIN of a key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Tried to init PIN of a key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Tried to change SO PIN of a key</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_temp</name>
    <message>
      <source>Type</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Bad template: %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Nothing</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Preset Template values</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>copy</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Save template as</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>XCA templates ( *.xca);; All files ( * )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>New Template</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Rename</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Export</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Change</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Duplicate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Create certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Create request</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_x509</name>
    <message>
      <source>CA</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>reflects the basic Constraints extension</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Serial</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>md5 fingerprint</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>sha1 fingerprint</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Start date</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>not Before</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Expiry date</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>not After</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Trust state</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revocation</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Plain View</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Tree View</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The certificate already exists in the database as:
'%1'
and so it was not imported</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Invalid public key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the new hexadecimal secret number for the QA process.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The QA process has been terminated by the user.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The key you selected for signing is not a private one.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Store the certificate to the key on the token '%1 (#%2)' ?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>New Certificate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Import PKCS#12</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import from PKCS#7</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Rename</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Show Details</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Extract public Key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Export</source>
      <translation>Exportar</translation>
    </message>
    <message>
      <source>Clipboard</source>
      <translation>Portapapeles</translation>
    </message>
    <message>
      <source>File</source>
      <translation>Archivo</translation>
    </message>
    <message>
      <source>Request</source>
      <translation>Solicitud</translation>
    </message>
    <message>
      <source>Security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Other token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Template</source>
      <translation>Plantilla</translation>
    </message>
    <message>
      <source>OpenSSL config</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation>Eliminar</translation>
    </message>
    <message>
      <source>Delete from Security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Trust</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Properties</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Generate CRL</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PKCS#7</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Sign</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Encrypt</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Renewal</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unrevoke</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Revoke</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>There was no key found for the Certificate: '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Not possible for a token key: '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Not possible for the token-key Certificate '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source> days</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_x509name</name>
    <message>
      <source>Subject</source>
      <translation>Sujeto</translation>
    </message>
    <message>
      <source>Complete distinguished name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Subject hash</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Hash to lookup certs in directories</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_x509req</name>
    <message>
      <source>Signed</source>
      <translation>Firma</translation>
    </message>
    <message>
      <source>whether the request is already signed or not</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unstructured name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Challenge password</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The certificate signing request already exists in the database as
'%1'
and thus was not stored</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certificate request ( *.pem *.der *.crl )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Certificate request export</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>New Request</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Extract public Key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Rename</source>
      <translation>Renombrar</translation>
    </message>
    <message>
      <source>Show Details</source>
      <translation>Mostrar detalles</translation>
    </message>
    <message>
      <source>Sign</source>
      <translation>Firma</translation>
    </message>
    <message>
      <source>Export</source>
      <translation>Importar</translation>
    </message>
    <message>
      <source>Clipboard</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>File</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Template</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>OpenSSL config</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>db_x509super</name>
    <message>
      <source>Key name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Internal name of the key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Save as OpenSSL config</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Config files ( *.conf *.cnf);; All files ( * )</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The following extensions were not ported into the template</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>kvView</name>
    <message>
      <source>Type</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Content</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pass_info</name>
    <message>
      <source>Password</source>
      <translation>Contraseña</translation>
    </message>
    <message>
      <source>PIN</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_base</name>
    <message>
      <source>Error opening file: '%1': %2</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Error writing to file: '%1': %2</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Error: </source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Internal error: Unexpected message: %1 %2</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_crl</name>
    <message>
      <source>Successfully imported the revokation list '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the revokation list '%1'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully created the revokation list '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 revokation lists: %2?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unable to load the revokation list in file %1. Tried PEM and DER formatted CRL.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No issuer given</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Wrong Size %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>unknown</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_evp</name>
    <message>
      <source>Failed to decrypt the key (bad password) </source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the password to decrypt the private key.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the password to decrypt the private key from file:
%1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unable to load the private key in file %1. Tried PEM and DER private, public and PKCS#8 key types.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the password to decrypt the private key: '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Password input aborted</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the database password for decrypting the key '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the password to protect the private key: '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the database password for encrypting the key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the password protecting the PKCS#8 key '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the export password for the private key '%1'</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_key</name>
    <message>
      <source>Successfully imported the %1 public key '%2'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 public key '%2'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully imported the %1 private key '%2'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 private key '%2'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully created the %1 private key '%2'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 keys: %2?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>public key</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Common</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Private</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Bogus</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PIN</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No password</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_multi</name>
    <message>
      <source>Seek failed</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_pkcs12</name>
    <message>
      <source>Please enter the password to decrypt the PKCS#12 file:
%1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unable to load the PKCS#12 (pfx) file %1.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>The supplied password was wrong (%1)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please enter the password to encrypt the PKCS#12 file</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No key or no Cert and no pkcs12</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_pkcs7</name>
    <message>
      <source>Unable to load the PKCS#7 file %1. Tried PEM and DER format.</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_scard</name>
    <message>
      <source>Successfully imported the token key '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the token key '%1'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully created the token key '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 keys: %2?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the private key '%1' from the token '%2 (#%3)' ?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>only RSA keys can be stored on tokens</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>This Key is already on the token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>PIN input aborted</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unable to find copied key on the token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Please insert card: %1 %2 [%3] with Serial: %4</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Public Key missmatch. Please re-import card</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unable to find generated key on card</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Wrong Size %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Token %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Failed to find the key on the token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Invalid Pin for the token</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_temp</name>
    <message>
      <source>Successfully imported the XCA template '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the XCA template '%1'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully created the XCA template '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 XCA templates: %2?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Wrong Size %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Template file content error (too small): %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Template file content error (bad size): %1 </source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Template file content error (bad length) :%1</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_x509</name>
    <message>
      <source>Successfully imported the certificate '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the certificate '%1'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully created the certificate '%1'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 certificates: %2?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unable to load the certificate in file %1. Tried PEM and DER certificate.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>This certificate is already on the security token</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the certificate '%1' from the token '%2 (#%3)'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>There is no key for signing !</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Wrong Size %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Not trusted</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Trust inherited</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Always Trusted</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>CRL expires: %1</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Yes</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>pki_x509req</name>
    <message>
      <source>Signing key not valid (public key)</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully imported the %1 certificate request '%2'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 certificate request '%2'?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Successfully created the %1 certificate request '%2'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete the %1 certificate requests: %2?</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unable to load the certificate request in file %1. Tried PEM, DER and SPKAC format.</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Signed</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Unhandled</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Wrong Size %1</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>v3ext</name>
    <message>
      <source>Add</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Delete</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Apply</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Validate</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Cancel</source>
      <translation>Cancelar</translation>
    </message>
    <message>
      <source>An email address or 'copy'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>An email address</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>a registered ID: OBJECT IDENTIFIER</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>a uniform resource indicator</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>a DNS domain name</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>an IP address</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Syntax: &lt;OID&gt;;TYPE:text like '1.2.3.4:UTF8:name'</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>No editing. Only 'copy' allowed here</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Validation failed:
'%1'
%2</source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Validation successfull:
'%1'</source>
      <translation type="unfinished"/>
    </message>
  </context>
  <context>
    <name>void</name>
    <message>
      <source>There was no key found for the Certificate: </source>
      <translation type="unfinished"/>
    </message>
    <message>
      <source>Import Certificate signing request</source>
      <translation type="unfinished"/>
    </message>
  </context>
</TS>
